@@ -29,28 +29,16 @@ class LazyReciever(object):
         method = self._find_method(name)
 
         def _(*args, **kwargs):
-            if name in self.target.self_generative_methods:
-                ret = method(self.target, *args, **kwargs)
-                reciever = LazyReciever(ret)
-                self.nested.append(reciever)
-                return reciever
-            else:
-                self.calls.append((method, args, kwargs))
-                return self
+            self.calls.append((method, args, kwargs))
+            return self
 
-        if name == 'image':
-            return method
-        else:
-            return _
+        return _
 
     def _find_method(self, name):
         for p in self.target.__class__.__mro__:
             if name in p.__dict__:
                 return p.__dict__[name]
 
-        if name == 'image':
-            return self.target.image
-
         raise AttributeError("%s instance has no attribute '%s'"
             % (self.target.__class__.__name__, name))
 
@@ -70,6 +58,7 @@ class LineJumpDrawFilter(LazyReciever):
         self.y_cross = {}
         self.forward = 'holizonal'
         self.jump_radius = jump_radius
+        self.jump_shifte = 0
 
     def _run(self):
         for recv in self.nested:
@@ -94,10 +83,11 @@ class LineJumpDrawFilter(LazyReciever):
             x1, x2 = x2, x1
 
         for x in sorted(self.x_cross.get(y, [])):
-            if x1 <= x and x <= x2:
+            if x1 < x and x < x2:
                 arckwargs = dict(kwargs)
                 del arckwargs['jump']
 
+                x += self.jump_shift
                 r = self.jump_radius
                 line = (XY(x1, y), XY(x - r, y))
                 self.target.line(line, **kwargs)
@@ -113,10 +103,11 @@ class LineJumpDrawFilter(LazyReciever):
             y1, y2 = y2, y1
 
         for y in sorted(self.y_cross.get(x, [])):
-            if y1 <= y and y <= y2:
+            if y1 < y and y < y2:
                 arckwargs = dict(kwargs)
                 del arckwargs['jump']
 
+                y += self.jump_shift
                 r = self.jump_radius
                 line = (XY(x, y1), XY(x, y - r))
                 self.target.line(line, **kwargs)
