@@ -25,8 +25,6 @@ from blockdiag.utils.PDFTextFolder import PDFTextFolder as TextFolder
 
 
 class PDFImageDraw(object):
-    self_generative_methods = []
-
     def __init__(self, filename, size, **kwargs):
         self.canvas = canvas.Canvas(filename, pagesize=size)
         self.size = size
@@ -103,27 +101,6 @@ class PDFImageDraw(object):
         params = self.set_render_params(**kwargs)
         self.canvas.rect(x, y, width, height, **params)
 
-    def point(self, xy, **kwargs):
-        fill = kwargs.get('fill')
-
-        if isinstance(xy, (list, tuple)) and isinstance(xy[0], (list, tuple)):
-            pass
-        else:
-            xy = [xy]
-
-        for pt in xy:
-            y = self.size[1] - pt[1]
-            box = (pt[0], y, pt[0] + 1, y + 1)
-            self.rectangle(box, fill=fill, outline=fill)
-
-    def label(self, box, string, **kwargs):
-        self.set_font(kwargs.get('font'), kwargs.get('fontsize', 11))
-        lines = TextFolder(box, string, adjustBaseline=True,
-                           canvas=self.canvas, **kwargs)
-
-        self.rectangle(lines.outlineBox(), fill='white', outline='black')
-        self.textarea(box, string, **kwargs)
-
     def text(self, xy, string, **kwargs):
         self.set_fill_color(kwargs.get('fill'))
         self.set_font(kwargs.get('font'), kwargs.get('fontsize', 11))
@@ -134,6 +111,10 @@ class PDFImageDraw(object):
         lines = TextFolder(box, string, adjustBaseline=True,
                            canvas=self.canvas, **kwargs)
 
+        if kwargs.get('outline'):
+            outline = kwargs.get('outline')
+            self.rectangle(lines.outlineBox(), fill='white', outline=outline)
+
         for string, xy in lines.each_line():
             self.text(xy, string, **kwargs)
 
